function [ymod,dyda] = funcs(x,a,ma,ndata)

% Eingabe-Parameter:  x  Zeilenvektor der x-Komponenten der geg. Punkte
%                     ndata  Zahl der geg. Punkte
%                     ma     Zahl der Fit-Parameter
%                     a      Zeilenvektor der guessed values fuer die Fit-Paramter

%  Ausgabe-Parameter:  ymod    Zeilenvektor mit den ndata Werten der Modellfunktion
%                      dyda    Matrix (1. Index=Nummer des Parameters,
%                                      2. Index=Nummer des Datenpunktes) mit den partiellen
%                              Ableitungen der Modellfunktion nach den Modellparametern


% y=a(1) * e^(-a(2)*t)

t = x;

dyda = zeros(ma,ndata);
    for j=1:ndata       % Schleife über die Messpunkte- numer
        
        %Ableitung nach den parametern
        dyda(1,j) = exp(-a(2) * t(j));
        dyda(2,j) = a(1) * exp(-a(2) * t(j)) .* -t(j);
	       
        %y werte
	ymod(j) = a(1) * exp(-a(2) * t(j));
    end
ymod = ymod';  